@@ -13,8 +13,8 @@ from .frosted_checker import FrostedCheckerMode
 from .goto_assignements import Assignment
 from .goto_assignements import GoToAssignmentsMode
 from .indenter import PyIndenterMode
+from .sh import PythonSH
 from .pep8_checker import PEP8CheckerMode
-from .syntax_highlighter import PyHighlighterMode
 
 
 __all__ = [
@@ -27,6 +27,6 @@ __all__ = [
     'Assignment',
     'GoToAssignmentsMode',
     'PyIndenterMode',
+    'PythonSH',
     'PEP8CheckerMode',
-    'PyHighlighterMode',
 ]
