@@ -1,5 +1,5 @@
 from pyqode.core.api import TextHelper
-from pyqode.core.qt.QtTest import QTest
+from pyqode.qt.QtTest import QTest
 from pyqode.python import panels
 
 from ..helpers import editor_open
